.. _likelihood_function:

Likelihood Function
===================

The ``autogalaxy_workspace`` contains Jupyter notebooks describing the (log) likelihood functions used by **PyAutoGalaxy**.

The notebooks provide a step-by-step guide of how **PyAutoGalaxy** fits galaxy data, with the aim to make
the analysis clear to readers without background experience in galaxy modeling and make the modeling less
of a "black box".

We recommend that when writing a paper using **PyAutoGalaxy** the author links to this GitHub repository when describing
their likelihood function.

Links to every notebook are provided at the GitHub repository linked to below. We recommend authors link to this
GitHub repository (as opposed to direct links to each) because the URLs to notebooks on the ``autogalaxy_workspace``
may change after papers are published.

By linking to this repository a permanent URL is provided.

https://github.com/Jammy2211/autogalaxy_likelihood_function